CustomMarkdownBuilder class abstract

Base class for custom markdown builders.

Implementers

Constructors

CustomMarkdownBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildWidget(Element element, TextStyle? style) Widget?
Builds the widget for the given element.
isBlockElement() bool
For block syntax has to return true.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visitElementAfter(Element element, TextStyle? style) Widget?
Builds a widget from the markdown element.
visitElementAfterWithContext(BuildContext context, Element element, TextStyle? preferredStyle, TextStyle? parentStyle) Widget?
Called when an Element has been reached, after its children have been visited.
inherited
visitElementBefore(Element element) → void
Called when an Element has been reached, before its children have been visited.
inherited
visitText(Text text, TextStyle? preferredStyle) Widget?
Called when a text node has been reached.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited