MarkdownTypingController class

Controller that manages typing animation for markdown text.

Inheritance

Constructors

MarkdownTypingController({String? fullText, Stream<String>? stream, AnimationConfig? config})
Creates a MarkdownTypingController with the given text and config.

Properties

config AnimationConfig
Animation configuration.
final
fullText String
Full text to animate (current accumulated text).
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isComplete bool
Whether the animation is complete.
no setter
isPaused bool
Whether the animation is paused.
no setter
isRunning bool
Whether the animation is currently running.
no setter
progress double
Current progress (0.0 to 1.0).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Current displayed text.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
jumpToEnd() → void
Jumps to the end of the animation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pause() → void
Pauses the typing animation.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Resets the animation to the beginning.
resume() Future<void>
Resumes the typing animation.
start() Future<void>
Starts the typing animation.
stop() → void
Stops the typing animation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited