streaming_markdown library
Classes
- AnimatedMarkdown
- Animated markdown widget with ChatGPT-style typing animation.
- AnimationConfig
- Configuration for markdown typing animation.
- ButtonBuilder
-
Builder for inline button widgets: [
button:Label] - ChipBuilder
-
Builder for inline chip widgets: [
chip:Label] - CustomInlineSyntax
- Base class for custom inline syntax.
- CustomMarkdownBuilder
- Base class for custom markdown builders.
- DynamicInlineSyntax
-
Generic inline syntax that automatically handles any key: [
key:content] This allows users to add custom builders without needing to create syntax classes. Can also accept custom regex patterns for more flexible matching. - InlineBuilder
- Base class for inline widget builders.
- MarkdownRenderer
- Renders markdown with custom builders and syntaxes.
- MarkdownStyleSheet
- Defines which TextStyle objects to use for which Markdown elements.
- MarkdownTypingController
- Controller that manages typing animation for markdown text.
- MathBuilder
-
Builder for math/LaTeX widgets: [
math:Formula] Note: This is a placeholder. For actual math rendering, integrate a math package. - SyntaxHighlighter
- Creates a format TextSpan given a string.
Enums
- AnimationMode
- Animation modes for markdown typing animation.
Typedefs
- MarkdownTapLinkCallback = void Function(String text, String? href, String title)
-
Signature for callbacks used by
MarkdownWidgetwhen the user taps a link. The callback will return the link text, destination, and title from the Markdown link tag in the document.